@@ -2,20 +2,19 @@
 
 function form_date(days)
     _check_required(days, 'number')
-
-    return os.date("%d-%b-%Y", os.time() - days * 60 * 60 * 24)
+    return os.date('%d-%b-%Y', os.time() - days * 60 * 60 * 24)
 end
 
 
 function get_password(prompt)
     _check_optional(prompt, 'string')
 
-    if (prompt ~= nil) then
+    if prompt ~= nil then
         io.write(prompt)
     else
         io.write('Enter password: ')
     end
-
+    io.flush()
     ifsys.noecho()
     local p = io.read()
     ifsys.echo()
@@ -28,8 +27,7 @@ function pipe_to(command, data)
     _check_required(command, 'string')
     _check_required(data, 'string')
 
-    f = ifsys.popen(command, "w")
-
+    f = ifsys.popen(command, 'w')
     ifsys.write(f, data)
 
     return ifsys.pclose(f)
@@ -38,12 +36,11 @@ end
 function pipe_from(command)
     _check_required(command, 'string')
 
-    f = ifsys.popen(command, "r")
-
+    f = ifsys.popen(command, 'r')
     local string = ''
-    while (true) do
+    while true do
         s = ifsys.read(f)
-        if (s ~= nil) then
+        if s ~= nil then
             string = string .. s
         else
             break
@@ -54,13 +51,25 @@ function pipe_from(command)
 end
 
 
-function become_daemon(interval, commands)
+function become_daemon(interval, commands, nochdir, noclose)
     _check_required(interval, 'number')
     _check_required(commands, 'function')
+    _check_optional(nochdir, 'boolean')
+    _check_optional(noclose, 'boolean')
 
-    ifsys.daemon()
-
+    if nochdir == nil then nochdir = false end
+    if noclose == nil then noclose = false end
+    ifsys.daemon(nochdir, noclose)
+    _daemon = true
     repeat
-        pcall(commands)
-    until (ifsys.sleep(interval) ~= 0)
+        for _, account in pairs(_imap) do
+            if not account._account.session then
+                account:_login_user(account)
+            end
+        end
+        commands()
+        collectgarbage()
+    until ifsys.sleep(interval) ~= 0
 end
+
+sleep = ifsys.sleep
